==> glue-1.93.0-sources.jar: software/amazon/awscdk/services/glue/Connection.java <==
package software.amazon.awscdk.services.glue;

/**
 * (experimental) An AWS Glue connection to a data source.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.24.0 (build b722f66)", date = "2021-03-11T13:46:44.482Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.glue.$Module.class, fqn = "@aws-cdk/aws-glue.Connection")
public class Connection extends software.amazon.awscdk.core.Resource implements software.amazon.awscdk.services.glue.IConnection {

    protected Connection(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected Connection(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param scope This parameter is required.
     * @param id This parameter is required.
     * @param props This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public Connection(final @org.jetbrains.annotations.NotNull software.constructs.Construct scope, final @org.jetbrains.annotations.NotNull java.lang.String id, final @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.glue.ConnectionProps props) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(scope, "scope is required"), java.util.Objects.requireNonNull(id, "id is required"), java.util.Objects.requireNonNull(props, "props is required") });
    }

    /**
     * (experimental) Creates a Connection construct that represents an external connection.
     * <p>
     * @param scope The scope creating construct (usually `this`). This parameter is required.
     * @param id The construct's id. This parameter is required.
     * @param connectionArn arn of external connection. This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.glue.IConnection fromConnectionArn(final @org.jetbrains.annotations.NotNull software.constructs.Construct scope, final @org.jetbrains.annotations.NotNull java.lang.String id, final @org.jetbrains.annotations.NotNull java.lang.String connectionArn) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.glue.Connection.class, "fromConnectionArn", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.glue.IConnection.class), new Object[] { java.util.Objects.requireNonNull(scope, "scope is required"), java.util.Objects.requireNonNull(id, "id is required"), java.util.Objects.requireNonNull(connectionArn, "connectionArn is required") });
    }

    /**
     * (experimental) Creates a Connection construct that represents an external connection.
     * <p>
     * @param scope The scope creating construct (usually `this`). This parameter is required.
     * @param id The construct's id. This parameter is required.
     * @param connectionName name of external connection. This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.glue.IConnection fromConnectionName(final @org.jetbrains.annotations.NotNull software.constructs.Construct scope, final @org.jetbrains.annotations.NotNull java.lang.String id, final @org.jetbrains.annotations.NotNull java.lang.String connectionName) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.glue.Connection.class, "fromConnectionName", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.glue.IConnection.class), new Object[] { java.util.Objects.requireNonNull(scope, "scope is required"), java.util.Objects.requireNonNull(id, "id is required"), java.util.Objects.requireNonNull(connectionName, "connectionName is required") });
    }

    /**
     * (experimental) Add additional connection parameters.
     * <p>
     * @param key parameter key. This parameter is required.
     * @param value parameter value. This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public void addProperty(final @org.jetbrains.annotations.NotNull java.lang.String key, final @org.jetbrains.annotations.NotNull java.lang.String value) {
        software.amazon.jsii.Kernel.call(this, "addProperty", software.amazon.jsii.NativeType.VOID, new Object[] { java.util.Objects.requireNonNull(key, "key is required"), java.util.Objects.requireNonNull(value, "value is required") });
    }

    /**
     * (experimental) The ARN of the connection.
     */
    @Override
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public @org.jetbrains.annotations.NotNull java.lang.String getConnectionArn() {
        return software.amazon.jsii.Kernel.get(this, "connectionArn", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
    }

    /**
     * (experimental) The name of the connection.
     */
    @Override
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public @org.jetbrains.annotations.NotNull java.lang.String getConnectionName() {
        return software.amazon.jsii.Kernel.get(this, "connectionName", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
    }

    /**
     * (experimental) A fluent builder for {@link software.amazon.awscdk.services.glue.Connection}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<software.amazon.awscdk.services.glue.Connection> {
        /**
         * @return a new instance of {@link Builder}.
         * @param scope This parameter is required.
         * @param id This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public static Builder create(final software.constructs.Construct scope, final java.lang.String id) {
            return new Builder(scope, id);
        }

        private final software.constructs.Construct scope;
        private final java.lang.String id;
        private final software.amazon.awscdk.services.glue.ConnectionProps.Builder props;

        private Builder(final software.constructs.Construct scope, final java.lang.String id) {
            this.scope = scope;
            this.id = id;
            this.props = new software.amazon.awscdk.services.glue.ConnectionProps.Builder();
        }

        /**
         * (experimental) The name of the connection.
         * <p>
         * Default: cloudformation generated name
         * <p>
         * @return {@code this}
         * @param connectionName The name of the connection. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder connectionName(final java.lang.String connectionName) {
            this.props.connectionName(connectionName);
            return this;
        }

        /**
         * (experimental) The description of the connection.
         * <p>
         * Default: no description
         * <p>
         * @return {@code this}
         * @param description The description of the connection. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder description(final java.lang.String description) {
            this.props.description(description);
            return this;
        }

        /**
         * (experimental) A list of criteria that can be used in selecting this connection.
         * <p>
         * This is useful for filtering the results of https://awscli.amazonaws.com/v2/documentation/api/latest/reference/glue/get-connections.html
         * <p>
         * Default: no match criteria
         * <p>
         * @return {@code this}
         * @param matchCriteria A list of criteria that can be used in selecting this connection. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder matchCriteria(final java.util.List<java.lang.String> matchCriteria) {
            this.props.matchCriteria(matchCriteria);
            return this;
        }

        /**
         * (experimental) Key-Value pairs that define parameters for the connection.
         * <p>
         * Default: empty properties
         * <p>
         * @return {@code this}
         * @see https://docs.aws.amazon.com/glue/latest/dg/aws-glue-programming-etl-connect.html
         * @param properties Key-Value pairs that define parameters for the connection. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder properties(final java.util.Map<java.lang.String, java.lang.String> properties) {
            this.props.properties(properties);
            return this;
        }

        /**
         * (experimental) The list of security groups needed to successfully make this connection e.g. to successfully connect to VPC.
         * <p>
         * Default: no security group
         * <p>
         * @return {@code this}
         * @param securityGroups The list of security groups needed to successfully make this connection e.g. to successfully connect to VPC. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder securityGroups(final java.util.List<? extends software.amazon.awscdk.services.ec2.ISecurityGroup> securityGroups) {
            this.props.securityGroups(securityGroups);
            return this;
        }

        /**
         * (experimental) The VPC subnet to connect to resources within a VPC.
         * <p>
         * See more at https://docs.aws.amazon.com/glue/latest/dg/start-connecting.html.
         * <p>
         * Default: no subnet
         * <p>
         * @return {@code this}
         * @param subnet The VPC subnet to connect to resources within a VPC. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder subnet(final software.amazon.awscdk.services.ec2.ISubnet subnet) {
            this.props.subnet(subnet);
            return this;
        }

        /**
         * (experimental) The type of the connection.
         * <p>
         * @return {@code this}
         * @param type The type of the connection. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder type(final software.amazon.awscdk.services.glue.ConnectionType type) {
            this.props.type(type);
            return this;
        }

        /**
         * @returns a newly built instance of {@link software.amazon.awscdk.services.glue.Connection}.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public software.amazon.awscdk.services.glue.Connection build() {
            return new software.amazon.awscdk.services.glue.Connection(
                this.scope,
                this.id,
                this.props.build()
            );
        }
    }
}

==> glue-1.182.0-sources.jar: software/amazon/awscdk/services/glue/Connection.java <==
package software.amazon.awscdk.services.glue;

/**
 * (experimental) An AWS Glue connection to a data source.
 * <p>
 * Example:
 * <p>
 * <blockquote><pre>
 * SecurityGroup securityGroup;
 * Subnet subnet;
 * Connection.Builder.create(this, "MyConnection")
 *         .type(ConnectionType.NETWORK)
 *         // The security groups granting AWS Glue inbound access to the data source within the VPC
 *         .securityGroups(List.of(securityGroup))
 *         // The VPC subnet which contains the data source
 *         .subnet(subnet)
 *         .build();
 * </pre></blockquote>
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.71.0 (build f1f58ae)", date = "2022-12-07T17:24:43.442Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.glue.$Module.class, fqn = "@aws-cdk/aws-glue.Connection")
public class Connection extends software.amazon.awscdk.core.Resource implements software.amazon.awscdk.services.glue.IConnection {

    protected Connection(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected Connection(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param scope This parameter is required.
     * @param id This parameter is required.
     * @param props This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public Connection(final @org.jetbrains.annotations.NotNull software.constructs.Construct scope, final @org.jetbrains.annotations.NotNull java.lang.String id, final @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.glue.ConnectionProps props) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(scope, "scope is required"), java.util.Objects.requireNonNull(id, "id is required"), java.util.Objects.requireNonNull(props, "props is required") });
    }

    /**
     * (experimental) Creates a Connection construct that represents an external connection.
     * <p>
     * @param scope The scope creating construct (usually `this`). This parameter is required.
     * @param id The construct's id. This parameter is required.
     * @param connectionArn arn of external connection. This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.glue.IConnection fromConnectionArn(final @org.jetbrains.annotations.NotNull software.constructs.Construct scope, final @org.jetbrains.annotations.NotNull java.lang.String id, final @org.jetbrains.annotations.NotNull java.lang.String connectionArn) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.glue.Connection.class, "fromConnectionArn", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.glue.IConnection.class), new Object[] { java.util.Objects.requireNonNull(scope, "scope is required"), java.util.Objects.requireNonNull(id, "id is required"), java.util.Objects.requireNonNull(connectionArn, "connectionArn is required") });
    }

    /**
     * (experimental) Creates a Connection construct that represents an external connection.
     * <p>
     * @param scope The scope creating construct (usually `this`). This parameter is required.
     * @param id The construct's id. This parameter is required.
     * @param connectionName name of external connection. This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.glue.IConnection fromConnectionName(final @org.jetbrains.annotations.NotNull software.constructs.Construct scope, final @org.jetbrains.annotations.NotNull java.lang.String id, final @org.jetbrains.annotations.NotNull java.lang.String connectionName) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.glue.Connection.class, "fromConnectionName", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.glue.IConnection.class), new Object[] { java.util.Objects.requireNonNull(scope, "scope is required"), java.util.Objects.requireNonNull(id, "id is required"), java.util.Objects.requireNonNull(connectionName, "connectionName is required") });
    }

    /**
     * (experimental) Add additional connection parameters.
     * <p>
     * @param key parameter key. This parameter is required.
     * @param value parameter value. This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public void addProperty(final @org.jetbrains.annotations.NotNull java.lang.String key, final @org.jetbrains.annotations.NotNull java.lang.String value) {
        software.amazon.jsii.Kernel.call(this, "addProperty", software.amazon.jsii.NativeType.VOID, new Object[] { java.util.Objects.requireNonNull(key, "key is required"), java.util.Objects.requireNonNull(value, "value is required") });
    }

    /**
     * (experimental) The ARN of the connection.
     */
    @Override
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public @org.jetbrains.annotations.NotNull java.lang.String getConnectionArn() {
        return software.amazon.jsii.Kernel.get(this, "connectionArn", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
    }

    /**
     * (experimental) The name of the connection.
     */
    @Override
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public @org.jetbrains.annotations.NotNull java.lang.String getConnectionName() {
        return software.amazon.jsii.Kernel.get(this, "connectionName", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
    }

    /**
     * (experimental) A fluent builder for {@link software.amazon.awscdk.services.glue.Connection}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<software.amazon.awscdk.services.glue.Connection> {
        /**
         * @return a new instance of {@link Builder}.
         * @param scope This parameter is required.
         * @param id This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public static Builder create(final software.constructs.Construct scope, final java.lang.String id) {
            return new Builder(scope, id);
        }

        private final software.constructs.Construct scope;
        private final java.lang.String id;
        private final software.amazon.awscdk.services.glue.ConnectionProps.Builder props;

        private Builder(final software.constructs.Construct scope, final java.lang.String id) {
            this.scope = scope;
            this.id = id;
            this.props = new software.amazon.awscdk.services.glue.ConnectionProps.Builder();
        }

        /**
         * (experimental) The name of the connection.
         * <p>
         * Default: cloudformation generated name
         * <p>
         * @return {@code this}
         * @param connectionName The name of the connection. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder connectionName(final java.lang.String connectionName) {
            this.props.connectionName(connectionName);
            return this;
        }

        /**
         * (experimental) The description of the connection.
         * <p>
         * Default: no description
         * <p>
         * @return {@code this}
         * @param description The description of the connection. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder description(final java.lang.String description) {
            this.props.description(description);
            return this;
        }

        /**
         * (experimental) A list of criteria that can be used in selecting this connection.
         * <p>
         * This is useful for filtering the results of https://awscli.amazonaws.com/v2/documentation/api/latest/reference/glue/get-connections.html
         * <p>
         * Default: no match criteria
         * <p>
         * @return {@code this}
         * @param matchCriteria A list of criteria that can be used in selecting this connection. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder matchCriteria(final java.util.List<java.lang.String> matchCriteria) {
            this.props.matchCriteria(matchCriteria);
            return this;
        }

        /**
         * (experimental) Key-Value pairs that define parameters for the connection.
         * <p>
         * Default: empty properties
         * <p>
         * @return {@code this}
         * @see <a href="https://docs.aws.amazon.com/glue/latest/dg/aws-glue-programming-etl-connect.html">https://docs.aws.amazon.com/glue/latest/dg/aws-glue-programming-etl-connect.html</a>
         * @param properties Key-Value pairs that define parameters for the connection. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder properties(final java.util.Map<java.lang.String, java.lang.String> properties) {
            this.props.properties(properties);
            return this;
        }

        /**
         * (experimental) The list of security groups needed to successfully make this connection e.g. to successfully connect to VPC.
         * <p>
         * Default: no security group
         * <p>
         * @return {@code this}
         * @param securityGroups The list of security groups needed to successfully make this connection e.g. to successfully connect to VPC. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder securityGroups(final java.util.List<? extends software.amazon.awscdk.services.ec2.ISecurityGroup> securityGroups) {
            this.props.securityGroups(securityGroups);
            return this;
        }

        /**
         * (experimental) The VPC subnet to connect to resources within a VPC.
         * <p>
         * See more at https://docs.aws.amazon.com/glue/latest/dg/start-connecting.html.
         * <p>
         * Default: no subnet
         * <p>
         * @return {@code this}
         * @param subnet The VPC subnet to connect to resources within a VPC. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder subnet(final software.amazon.awscdk.services.ec2.ISubnet subnet) {
            this.props.subnet(subnet);
            return this;
        }

        /**
         * (experimental) The type of the connection.
         * <p>
         * @return {@code this}
         * @param type The type of the connection. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder type(final software.amazon.awscdk.services.glue.ConnectionType type) {
            this.props.type(type);
            return this;
        }

        /**
         * @returns a newly built instance of {@link software.amazon.awscdk.services.glue.Connection}.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public software.amazon.awscdk.services.glue.Connection build() {
            return new software.amazon.awscdk.services.glue.Connection(
                this.scope,
                this.id,
                this.props.build()
            );
        }
    }
}
